Learn R Programming

nlmm (version 1.1.1)

Laplace: The Laplace Distribution

Description

Density, distribution function, quantile function and random generation for the (symmetric) Laplace distribution.

Usage

dl(x, mu = 0, sigma = 1, log = FALSE)
pl(x, mu = 0, sigma = 1, lower.tail = TRUE, log.p = FALSE)
ql(p, mu = 0, sigma = 1, lower.tail = TRUE, log.p = FALSE)
rl(n, mu = 0, sigma = 1)

Value

dl gives the density and rl generates random deviates.

Arguments

x

vector of quantiles.

p

vector of probabilities.

n

number of observations.

mu

location parameter.

sigma

positive scale parameter.

log,log.p

logical; if TRUE, probabilities are log--transformed.

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\) otherwise, \(P[X > x]\). Similarly for quantiles.

Author

Marco Geraci

Details

The Laplace distribution has density $$ f(x) = \frac{1}{\sqrt{2}\sigma}e^{-\frac{\sqrt(2)}{\sigma} |x - \mu|} $$ where \(\mu\) is the location parameter and \(\sigma\) is the scale parameter. Note that based on this parameterization, the distribution has variance \(\sigma^2\).

References

Kotz, S., Kozubowski, T., and Podgorski, K. (2001). The Laplace distribution and generalizations. Boston, MA: Birkhauser.

See Also

MultivariateLaplace, GenLaplace