Learn R Programming

nlmm (version 1.1.1)

lrt_nlmm: Likelihood Ratio Test for Generalized Laplace Mixed-Effects Models

Description

This function is used to perform a likelihood ratio test for two fitted generalized Laplace mixed-effects models.

Usage

lrt_nlmm(object0, object1)
# S3 method for lrt_nlmm
print(x, digits = max(3, getOption("digits") - 3), ...)

Value

An object of class lrt_nlmm is a list containing the following components:

statistic

the value of the test statistic

p.value

the p-value of the test

df

either the degrees of freedom of a chi-squared test or the weights of a chi-bar-squared test

V

the matrix based on which the weights for the chi-bar-squared test are calculated

alpha

values of the shape parameter in the constrained object

alpha.index

index of the constrained shape parameter

chibar

logical flag. If TRUE, the test statistic is a chi-bar

Arguments

object0

object of class nlmm with estimates of the constrained model.

object1

object of class nlmm with estimates of the unconstrained model.

x

a lrt_nlmm object.

digits

a non-null value for digits specifies the minimum number of significant digits to be printed in values.

...

not used.

Author

Marco Geraci and Alessio Farcomeni

References

Geraci, M. and Farcomeni A. (2020). A family of linear mixed-effects models using the generalized Laplace distribution. Statistical Methods in Medical Research, 29(9), 2665-2682.

See Also

nlmm