Learn R Programming

nlmm (version 1.1.1)

ranef.nlmm: Extract Random Effects

Description

This function computes random effects for a linear quantile mixed model.

Usage

# S3 method for nlmm
ranef(object, ...)

Value

a data frame of predicted random effects.

Arguments

object

an object of class nlmm.

...

not used.

Author

Marco Geraci

Details

The prediction of the random effects is done via estimated best linear prediction (Geraci and Farcomeni, 2019). The generic function ranef is imported from the nlme package (Pinheiro et al, 2014).

References

Geraci, M. and Farcomeni A. (2020). A family of linear mixed-effects models using the generalized Laplace distribution. Statistical Methods in Medical Research, 29(9), 2665-2682.

Pinheiro J, Bates D, DebRoy S, Sarkar D and R Core Team (2014). nlme: Linear and Nonlinear Mixed Effects Models. R package version 3.1-117, https://CRAN.R-project.org/package=nlme.

See Also

nlmm, fixef.nlmm

Examples

Run this code
if (FALSE) {
data(rats)
fit <- nlmm(y ~ trt*time, random = ~ time, group = id, data = rats,
control = nlmmControl(multistart = FALSE))

# Predicted random intercepts and slopes
ranef(fit)
}

Run the code above in your browser using DataLab