nlmm ObjectThe residuals at level 0 correspond to population residuals (based only on the fixed effects estimates). The residuals at level 1 are obtained by adding the best linear predictions of the random effects to the predictions at level 0 and the subtracting these from the model response.
# S3 method for nlmm
residuals(object, level = 0, ...)a matrix of residuals.
an nlmm object.
an optional integer vector giving the level of grouping to be used in obtaining the predictions. Level zero corresponds to the population residuals.
not used.
Marco Geraci
Geraci, M. and Farcomeni A. (2020). A family of linear mixed-effects models using the generalized Laplace distribution. Statistical Methods in Medical Research, 29(9), 2665-2682.
nlmm, predict.nlmm, fixef.nlmm, ranef.nlmm,