Learn R Programming

nlmm (version 1.1.1)

summary.nlmm: Summary for an nlmm Object

Description

Summary method for class nlmm.

Usage

# S3 method for nlmm
summary(object, alpha = 0.05, ...)

Value

an object of class summary.nlmm. The function summary.nlmm computes and returns a list of summary statistics of the fitted generalized Laplace mixed-effects model given in object, using the components (list elements) from its argument, plus

tTable

a matrix with estimates, standard errors, etc.

Arguments

object

an object of class nlmm.

alpha

significance level.

...

not used.

Author

Marco Geraci

Details

print.summary.nlmm formats the coefficients, standard errors, etc. and additionally gives `significance stars'.

See Also

print.summary.nlmm nlmm

Examples

Run this code
if (FALSE) {
data(rats)
fit <- nlmm(y ~ trt*time, random = ~ 1, group = id, data = rats,
control = nlmmControl(multistart = FALSE))
summary(fit)

}

Run the code above in your browser using DataLab