Density, distribution function, quantile function and random generation for the univariate symmetric generalized Laplace distribution.
dgl(x, sigma = 1, shape = 1, log = FALSE)
pgl(x, sigma = 1, shape = 1, lower.tail = TRUE, log.p = FALSE)
qgl(p, sigma = 1, shape = 1, lower.tail = TRUE, log.p = FALSE)
rgl(n, sigma = 1, shape = 1)
dgl gives the density, pgl gives the distribution function, qgl gives the quantile function, and rgl generates random deviates.
vector of quantiles.
vector of probabilities.
number of observations.
positive scale parameter.
shape parameter.
logical; if TRUE, probabilities are log--transformed.
logical; if TRUE (default), probabilities are \(P[X \le x]\) otherwise, \(P[X > x]\). Similarly for quantiles.
Marco Geraci
The univariate symmetric generalized Laplace distribution (Kotz et al, 2001, p.190) has density $$ f(x) = \frac{2}{\sqrt{2\pi}\Gamma(s)\sigma^{s+1/2}}(\frac{|x|}{\sqrt{2}})^{\omega}B_{\omega}(\frac{\sqrt{2}|x|}{\sigma}) $$ where \(\sigma\) is the scale parameter, \(\omega = s - 1/2\), and \(s\) is the shape parameter. \(\Gamma\) denotes the Gamma function and \(B_{u}\) the modified Bessel function of the third kind with index \(u\). The variance is \(s\sigma^{2}\).
This distribution is the univariate and symmetric case of MultivariateGenLaplace.
Kotz, S., Kozubowski, T., and Podgorski, K. (2001). The Laplace distribution and generalizations. Boston, MA: Birkhauser.
MultivariateGenLaplace