This function is used to perform a likelihood ratio test for two fitted generalized Laplace mixed-effects models.
lrt_nlmm(object0, object1)
# S3 method for lrt_nlmm
print(x, digits = max(3, getOption("digits") - 3), ...)An object of class lrt_nlmm is a list containing the following components:
the value of the test statistic
the p-value of the test
either the degrees of freedom of a chi-squared test or the weights of a chi-bar-squared test
the matrix based on which the weights for the chi-bar-squared test are calculated
values of the shape parameter in the constrained object
index of the constrained shape parameter
logical flag. If TRUE, the test statistic is a chi-bar
object of class nlmm with estimates of the constrained model.
object of class nlmm with estimates of the unconstrained model.
a lrt_nlmm object.
a non-null value for digits specifies the minimum number of significant digits to be printed in values.
not used.
Marco Geraci and Alessio Farcomeni
Geraci, M. and Farcomeni A. (2020). A family of linear mixed-effects models using the generalized Laplace distribution. Statistical Methods in Medical Research, 29(9), 2665-2682.
nlmm