# S3 method for nlmm
summary(object, alpha = 0.05, ...)
Value
an object of class summary.nlmm. The function summary.nlmm computes and returns a list of summary statistics of the fitted generalized Laplace mixed-effects model given in object, using the components (list elements) from its argument, plus